@@ -288,9 +288,9 @@ var getHorizontalBarPoints = function (position, sign, cr) {
   };
 
   var topPoints = getHalfPoints("top");
-  var bottomPoints = getHalfPoints("bottom"); // eslint-disable-next-line no-magic-numbers
-
-  return [bottomPoints[1], bottomPoints[0]].concat(_toConsumableArray(topPoints), [bottomPoints[3], bottomPoints[2]]);
+  var bottomPoints = getHalfPoints("bottom");
+  return [bottomPoints[1], bottomPoints[0]].concat(_toConsumableArray(topPoints), [// eslint-disable-next-line no-magic-numbers
+  bottomPoints[3], bottomPoints[2]]);
 }; // eslint-disable-next-line max-params
 
 
@@ -468,4 +468,15 @@ export var getVerticalPolarBarPath = function (props, cornerRadius) {
     return memo;
   }, "");
   return "".concat(path, " z");
+};
+export var getBarPath = function (props, width, cornerRadius) {
+  if (props.getPath) {
+    return getCustomBarPath(props, width);
+  }
+
+  return props.horizontal ? getHorizontalBarPath(props, width, cornerRadius) : getVerticalBarPath(props, width, cornerRadius);
+};
+export var getPolarBarPath = function (props, cornerRadius) {
+  // TODO Radial bars
+  return getVerticalPolarBarPath(props, cornerRadius);
 };
\ No newline at end of file
