@@ -3,7 +3,6 @@
  *  Licensed under the MIT License. See License.txt in the project root for license information.
  *--------------------------------------------------------------------------------------------*/
 import * as browser from './browser.js';
-import { domEvent } from './event.js';
 import { StandardKeyboardEvent } from './keyboardEvent.js';
 import { StandardMouseEvent } from './mouseEvent.js';
 import { TimeoutTimer } from '../common/async.js';
@@ -688,8 +687,8 @@ class FocusTracker extends Disposable {
                 }
             }
         };
-        this._register(domEvent(element, EventType.FOCUS, true)(onFocus));
-        this._register(domEvent(element, EventType.BLUR, true)(onBlur));
+        this._register(addDisposableListener(element, EventType.FOCUS, onFocus, true));
+        this._register(addDisposableListener(element, EventType.BLUR, onBlur, true));
     }
 }
 export function trackFocus(element) {
@@ -838,7 +837,7 @@ export class ModifierKeyEmitter extends Emitter {
             ctrlKey: false,
             metaKey: false
         };
-        this._subscriptions.add(domEvent(window, 'keydown', true)(e => {
+        this._subscriptions.add(addDisposableListener(window, 'keydown', e => {
             if (e.defaultPrevented) {
                 return;
             }
@@ -874,8 +873,8 @@ export class ModifierKeyEmitter extends Emitter {
                 this._keyStatus.event = e;
                 this.fire(this._keyStatus);
             }
-        }));
-        this._subscriptions.add(domEvent(window, 'keyup', true)(e => {
+        }, true));
+        this._subscriptions.add(addDisposableListener(window, 'keyup', e => {
             if (e.defaultPrevented) {
                 return;
             }
@@ -905,19 +904,19 @@ export class ModifierKeyEmitter extends Emitter {
                 this._keyStatus.event = e;
                 this.fire(this._keyStatus);
             }
-        }));
-        this._subscriptions.add(domEvent(document.body, 'mousedown', true)(e => {
+        }, true));
+        this._subscriptions.add(addDisposableListener(document.body, 'mousedown', () => {
             this._keyStatus.lastKeyPressed = undefined;
-        }));
-        this._subscriptions.add(domEvent(document.body, 'mouseup', true)(e => {
+        }, true));
+        this._subscriptions.add(addDisposableListener(document.body, 'mouseup', () => {
             this._keyStatus.lastKeyPressed = undefined;
-        }));
-        this._subscriptions.add(domEvent(document.body, 'mousemove', true)(e => {
+        }, true));
+        this._subscriptions.add(addDisposableListener(document.body, 'mousemove', e => {
             if (e.buttons) {
                 this._keyStatus.lastKeyPressed = undefined;
             }
-        }));
-        this._subscriptions.add(domEvent(window, 'blur')(e => {
+        }, true));
+        this._subscriptions.add(addDisposableListener(window, 'blur', () => {
             this.resetKeyStatus();
         }));
     }
