@@ -189,7 +189,7 @@ export class Delayer {
         }
     }
     dispose() {
-        this.cancelTimeout();
+        this.cancel();
     }
 }
 /**
@@ -209,9 +209,6 @@ export class ThrottledDelayer {
     trigger(promiseFactory, delay) {
         return this.delayer.trigger(() => this.throttler.queue(promiseFactory), delay);
     }
-    cancel() {
-        this.delayer.cancel();
-    }
     dispose() {
         this.delayer.dispose();
     }
@@ -436,37 +433,6 @@ export class IdleValue {
 //#region Promises
 export var Promises;
 (function (Promises) {
-    /**
-     * A polyfill of `Promise.allSettled`: returns after all promises have
-     * resolved or rejected and provides access to each result or error
-     * in the order of the original passed in promises array.
-     * See: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Promise/allSettled
-     */
-    function allSettled(promises) {
-        return __awaiter(this, void 0, void 0, function* () {
-            if (typeof Promise.allSettled === 'function') {
-                return allSettledNative(promises); // in some environments we can benefit from native implementation
-            }
-            return allSettledShim(promises);
-        });
-    }
-    Promises.allSettled = allSettled;
-    function allSettledNative(promises) {
-        return __awaiter(this, void 0, void 0, function* () {
-            return Promise.allSettled(promises);
-        });
-    }
-    function allSettledShim(promises) {
-        return __awaiter(this, void 0, void 0, function* () {
-            return Promise.all(promises.map(promise => (promise.then(value => {
-                const fulfilled = { status: 'fulfilled', value };
-                return fulfilled;
-            }, error => {
-                const rejected = { status: 'rejected', reason: error };
-                return rejected;
-            }))));
-        });
-    }
     /**
      * A drop-in replacement for `Promise.all` with the only difference
      * that the method awaits every promise to either fulfill or reject.
