@@ -42,6 +42,8 @@ export var Schemas;
     Schemas.vscodeNotebookCell = 'vscode-notebook-cell';
     Schemas.vscodeNotebookCellMetadata = 'vscode-notebook-cell-metadata';
     Schemas.vscodeNotebookCellOutput = 'vscode-notebook-cell-output';
+    Schemas.vscodeInteractive = 'vscode-interactive';
+    Schemas.vscodeInteractiveInput = 'vscode-interactive-input';
     Schemas.vscodeSettings = 'vscode-settings';
     Schemas.vscodeWorkspaceTrust = 'vscode-workspace-trust';
     Schemas.vscodeTerminal = 'vscode-terminal';
@@ -109,9 +111,17 @@ class FileAccessImpl {
         if (uri.scheme === Schemas.vscodeRemote) {
             return RemoteAuthorities.rewrite(uri);
         }
+        let convertToVSCodeFileResource = false;
         // Only convert the URI if we are in a native context and it has `file:` scheme
         // and we have explicitly enabled the conversion (sandbox, or VSCODE_BROWSER_CODE_LOADING)
         if (platform.isNative && (__forceCodeFileUri || platform.isPreferringBrowserCodeLoad) && uri.scheme === Schemas.file) {
+            convertToVSCodeFileResource = true;
+        }
+        // Also convert `file:` URIs in the web worker extension host (running in desktop) case
+        if (uri.scheme === Schemas.file && typeof platform.globals.importScripts === 'function' && platform.globals.origin === 'vscode-file://vscode-app') {
+            convertToVSCodeFileResource = true;
+        }
+        if (convertToVSCodeFileResource) {
             return uri.with({
                 scheme: Schemas.vscodeFileResource,
                 // We need to provide an authority here so that it can serve
