@@ -8,7 +8,7 @@ import * as platform from '../../../../base/common/platform.js';
 import { RangeUtil } from './rangeUtil.js';
 import { HorizontalRange, VisibleRanges } from '../../../common/view/renderingContext.js';
 import { LineDecoration } from '../../../common/viewLayout/lineDecorations.js';
-import { CharacterMapping, RenderLineInput, renderViewLine, LineRange } from '../../../common/viewLayout/viewLineRenderer.js';
+import { RenderLineInput, renderViewLine, LineRange, DomPosition } from '../../../common/viewLayout/viewLineRenderer.js';
 import { ColorScheme } from '../../../../platform/theme/common/theme.js';
 import { EditorFontLigatures } from '../../../common/config/editorOptions.js';
 const canUseFastRenderedViewLine = (function () {
@@ -298,12 +298,8 @@ class FastRenderedViewLine {
         return [new HorizontalRange(startPosition, endPosition - startPosition)];
     }
     _getCharPosition(column) {
-        const charOffset = this._characterMapping.getAbsoluteOffsets();
-        if (charOffset.length === 0) {
-            // No characters on this line
-            return 0;
-        }
-        return Math.round(this._charWidth * charOffset[column - 1]);
+        const charOffset = this._characterMapping.getAbsoluteOffset(column);
+        return Math.round(this._charWidth * charOffset);
     }
     getColumnOfNodeOffset(lineNumber, spanNode, offset) {
         const spanNodeTextContentLength = spanNode.textContent.length;
@@ -312,8 +308,7 @@ class FastRenderedViewLine {
             spanNode = spanNode.previousSibling;
             spanIndex++;
         }
-        const charOffset = this._characterMapping.partDataToCharOffset(spanIndex, spanNodeTextContentLength, offset);
-        return charOffset + 1;
+        return this._characterMapping.getColumn(new DomPosition(spanIndex, offset), spanNodeTextContentLength);
     }
 }
 /**
@@ -441,17 +436,15 @@ class RenderedViewLine {
             // This branch helps in the case of whitespace only lines which have a width set
             return this.getWidth();
         }
-        const partData = this._characterMapping.charOffsetToPartData(column - 1);
-        const partIndex = CharacterMapping.getPartIndex(partData);
-        const charOffsetInPart = CharacterMapping.getCharIndex(partData);
-        const r = RangeUtil.readHorizontalRanges(this._getReadingTarget(domNode), partIndex, charOffsetInPart, partIndex, charOffsetInPart, context.clientRectDeltaLeft, context.endNode);
+        const domPosition = this._characterMapping.getDomPosition(column);
+        const r = RangeUtil.readHorizontalRanges(this._getReadingTarget(domNode), domPosition.partIndex, domPosition.charIndex, domPosition.partIndex, domPosition.charIndex, context.clientRectDeltaLeft, context.endNode);
         if (!r || r.length === 0) {
             return -1;
         }
         const result = r[0].left;
         if (this.input.isBasicASCII) {
-            const charOffset = this._characterMapping.getAbsoluteOffsets();
-            const expectedResult = Math.round(this.input.spaceWidth * charOffset[column - 1]);
+            const charOffset = this._characterMapping.getAbsoluteOffset(column);
+            const expectedResult = Math.round(this.input.spaceWidth * charOffset);
             if (Math.abs(expectedResult - result) <= 1) {
                 return expectedResult;
             }
@@ -463,13 +456,9 @@ class RenderedViewLine {
             // This branch helps IE with bidi text & gives a performance boost to other browsers when reading visible ranges for an entire line
             return [new HorizontalRange(0, this.getWidth())];
         }
-        const startPartData = this._characterMapping.charOffsetToPartData(startColumn - 1);
-        const startPartIndex = CharacterMapping.getPartIndex(startPartData);
-        const startCharOffsetInPart = CharacterMapping.getCharIndex(startPartData);
-        const endPartData = this._characterMapping.charOffsetToPartData(endColumn - 1);
-        const endPartIndex = CharacterMapping.getPartIndex(endPartData);
-        const endCharOffsetInPart = CharacterMapping.getCharIndex(endPartData);
-        return RangeUtil.readHorizontalRanges(this._getReadingTarget(domNode), startPartIndex, startCharOffsetInPart, endPartIndex, endCharOffsetInPart, context.clientRectDeltaLeft, context.endNode);
+        const startDomPosition = this._characterMapping.getDomPosition(startColumn);
+        const endDomPosition = this._characterMapping.getDomPosition(endColumn);
+        return RangeUtil.readHorizontalRanges(this._getReadingTarget(domNode), startDomPosition.partIndex, startDomPosition.charIndex, endDomPosition.partIndex, endDomPosition.charIndex, context.clientRectDeltaLeft, context.endNode);
     }
     /**
      * Returns the column for the text found at a specific offset inside a rendered dom node
@@ -481,8 +470,7 @@ class RenderedViewLine {
             spanNode = spanNode.previousSibling;
             spanIndex++;
         }
-        const charOffset = this._characterMapping.partDataToCharOffset(spanIndex, spanNodeTextContentLength, offset);
-        return charOffset + 1;
+        return this._characterMapping.getColumn(new DomPosition(spanIndex, offset), spanNodeTextContentLength);
     }
 }
 class WebKitRenderedViewLine extends RenderedViewLine {
