@@ -393,6 +393,12 @@ export function registerDocumentRangeSemanticTokensProvider(languageId, provider
 export function registerInlineCompletionsProvider(languageId, provider) {
     return modes.InlineCompletionsProviderRegistry.register(languageId, provider);
 }
+/**
+ * Register an inlay hints provider.
+ */
+export function registerInlayHintsProvider(languageId, provider) {
+    return modes.InlayHintsProviderRegistry.register(languageId, provider);
+}
 /**
  * @internal
  */
@@ -431,6 +437,7 @@ export function createMonacoLanguagesAPI() {
         registerDocumentSemanticTokensProvider: registerDocumentSemanticTokensProvider,
         registerDocumentRangeSemanticTokensProvider: registerDocumentRangeSemanticTokensProvider,
         registerInlineCompletionsProvider: registerInlineCompletionsProvider,
+        registerInlayHintsProvider: registerInlayHintsProvider,
         // enums
         DocumentHighlightKind: standaloneEnums.DocumentHighlightKind,
         CompletionItemKind: standaloneEnums.CompletionItemKind,
