@@ -560,6 +560,9 @@ function tagToString(tag) {
         if (rest.length > 0)
             tagLabel += " \u2014 " + rest.map(function (r) { return r.text; }).join(' ');
     }
+    else if (Array.isArray(tag.text)) {
+        tagLabel += " \u2014 " + tag.text.map(function (r) { return r.text; }).join(' ');
+    }
     else if (tag.text) {
         tagLabel += " \u2014 " + tag.text;
     }
