@@ -14,11 +14,13 @@ var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefau
 
 var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
 
-var warning = require("fbjs/lib/warning");
+var warning = require("fbjs/lib/warning"); // $FlowFixMe[method-unbinding] added when improving typing for this parameters
+
 
 var hasOwnProperty = Object.prototype.hasOwnProperty;
 
 var _require = require('../util/RelayConcreteNode'),
+    ACTOR_CHANGE = _require.ACTOR_CHANGE,
     CONDITION = _require.CONDITION,
     CLIENT_COMPONENT = _require.CLIENT_COMPONENT,
     CLIENT_EXTENSION = _require.CLIENT_EXTENSION,
@@ -90,6 +92,9 @@ if (process.env.NODE_ENV !== "production") {
       case FLIGHT_FIELD:
         return validateField(optimisticResponse, selection, context);
 
+      case ACTOR_CHANGE:
+        return validateField(optimisticResponse, selection.linkedField, context);
+
       case INLINE_FRAGMENT:
         var type = selection.type;
         var isConcreteType = selection.abstractKey == null;
