@@ -10,7 +10,7 @@
 // flowlint ambiguous-object-type:error
 'use strict';
 
-var _global$ErrorUtils$ap, _global$ErrorUtils;
+var _global$ErrorUtils$ap, _global, _global$ErrorUtils;
 
 var RelayReader = require('./RelayReader');
 
@@ -26,7 +26,7 @@ var invariant = require('invariant');
 
 var warning = require("fbjs/lib/warning");
 
-var applyWithGuard = (_global$ErrorUtils$ap = (_global$ErrorUtils = global.ErrorUtils) === null || _global$ErrorUtils === void 0 ? void 0 : _global$ErrorUtils.applyWithGuard) !== null && _global$ErrorUtils$ap !== void 0 ? _global$ErrorUtils$ap : function (callback, context, args, onError, name) {
+var applyWithGuard = (_global$ErrorUtils$ap = (_global = global) === null || _global === void 0 ? void 0 : (_global$ErrorUtils = _global.ErrorUtils) === null || _global$ErrorUtils === void 0 ? void 0 : _global$ErrorUtils.applyWithGuard) !== null && _global$ErrorUtils$ap !== void 0 ? _global$ErrorUtils$ap : function (callback, context, args, onError, name) {
   return callback.apply(context, args);
 };
 /**
@@ -149,11 +149,25 @@ var RelayPublishQueue = /*#__PURE__*/function () {
   ;
 
   _proto.run = function run(sourceOperation) {
+    var runWillClearGcHold = this._appliedOptimisticUpdates === 0 && !!this._gcHold;
+    var runIsANoop = // this._pendingBackupRebase is true if an applied optimistic
+    // update has potentially been reverted or if this._pendingData is not empty.
+    !this._pendingBackupRebase && this._pendingOptimisticUpdates.size === 0 && !runWillClearGcHold;
+
     if (process.env.NODE_ENV !== "production") {
+      process.env.NODE_ENV !== "production" ? warning(!runIsANoop, 'RelayPublishQueue.run was called, but the call would have been a noop.') : void 0;
       process.env.NODE_ENV !== "production" ? warning(this._isRunning !== true, 'A store update was detected within another store update. Please ' + "make sure new store updates aren't being executed within an " + 'updater function for a different update.') : void 0;
       this._isRunning = true;
     }
 
+    if (runIsANoop) {
+      if (process.env.NODE_ENV !== "production") {
+        this._isRunning = false;
+      }
+
+      return [];
+    }
+
     if (this._pendingBackupRebase) {
       if (this._hasStoreSnapshot) {
         this._store.restore();
@@ -299,15 +313,19 @@ var RelayPublishQueue = /*#__PURE__*/function () {
             updater = optimisticUpdate.updater;
         var source = payload.source,
             fieldPayloads = payload.fieldPayloads;
-        var recordSourceSelectorProxy = new RelayRecordSourceSelectorProxy(mutator, recordSourceProxy, operation.fragment);
-        var selectorData;
 
         if (source) {
           recordSourceProxy.publishSource(source, fieldPayloads);
-          selectorData = lookupSelector(source, operation.fragment);
         }
 
         if (updater) {
+          var selectorData;
+
+          if (source) {
+            selectorData = lookupSelector(source, operation.fragment);
+          }
+
+          var recordSourceSelectorProxy = new RelayRecordSourceSelectorProxy(mutator, recordSourceProxy, operation.fragment);
           applyWithGuard(updater, null, [recordSourceSelectorProxy, selectorData], null, 'RelayPublishQueue:applyUpdates');
         }
       }
