@@ -36,6 +36,7 @@ function inlineDataFragmentTransform(context) {
 }
 
 function visitFragment(fragment) {
+  // $FlowFixMe[incompatible-use]
   var transformedFragment = this.traverse(fragment);
   var inlineDirective = transformedFragment.directives.find(function (directive) {
     return directive.name === 'inline';
@@ -56,7 +57,9 @@ function visitFragment(fragment) {
 }
 
 function visitFragmentSpread(fragmentSpread) {
-  var transformedFragmentSpread = this.traverse(fragmentSpread);
+  // $FlowFixMe[incompatible-use]
+  var transformedFragmentSpread = this.traverse(fragmentSpread); // $FlowFixMe[incompatible-use]
+
   var context = this.getContext();
   var fragment = context.get(transformedFragmentSpread.name);
 
@@ -72,7 +75,8 @@ function visitFragmentSpread(fragmentSpread) {
 
   if (transformedFragmentSpread.directives.length > 0) {
     throw createUserError('Directives on fragment spreads for @inline fragments are not yet ' + 'supported', [transformedFragmentSpread.loc]);
-  }
+  } // $FlowFixMe[incompatible-use]
+
 
   var transformedFragment = this.visit(fragment);
   return {
